@@ -21,8 +21,8 @@ class HTTP(Schedule):
                     "key": "Content-Type",
                     "value": "application/octet-stream",
                 },
-                "body": self.payload
+                "body": self.payload.encode()
             },
-            "schedule": self.cors,
+            "schedule": self.cron,
             "time_zone": "Europe/Amsterdam"
         }
