@@ -12,12 +12,12 @@ class Schedule(ABC):
     """
 
     name: str
-    cors: str
-    payload: dict
+    cron: str
+    payload: str
     description: str
 
     def __post_init__(self):
-        assert croniter.is_valid(self.cors), 'Cors is wrong'
+        assert croniter.is_valid(self.cron), 'cron is wrong'
 
     @abstractmethod
     def asdict(self, base_name, project) -> dict:
