@@ -36,7 +36,7 @@ class StorageClient(Client):
 
         new_blobs = []
         for i in range(0, len(blobs), 32):
-            composed_blob_name = f'composed/{n}:{i}_{blob_name}.json'
+            composed_blob_name = f'composed/{blob_name}_rec{n}_n{i}.json'
             self.bucket.blob(composed_blob_name).compose(blobs[i:i + 32])
             new_blobs.append(self.bucket.get_blob(composed_blob_name))
 
@@ -54,9 +54,6 @@ class StorageClient(Client):
     def __list_to_storage(self, objects, objects_name, batch_size):
         assert len(objects) > 0, 'List is empty. No data is send'
 
-        random_string = ''.join(random.choice(string.ascii_lowercase) for _ in
-                                range(12))  # Make blob_base_name unique so processes don't interact
-        blob_base_name = f'{objects_name}_{random_string}'  # Generate a dynamic name from the object
         blobs = []
 
         # Create batches and store them in multiple blob files. Warning blob files can be to big for Bigquery.
@@ -64,7 +61,7 @@ class StorageClient(Client):
             batch = objects[i:i + batch_size]
             nl_json_batch = nlj.dumps([rec_to_json(item) for item in batch])
             # Blobs will be stored in folder import
-            blob = self.bucket.blob(f'import/{blob_base_name}.json')
+            blob = self.bucket.blob(f'import/{objects_name}_n{i}_{generate_random_string()}.json')  # Generate a dynamic name from the object
             blobs.append(blob)
             blob.upload_from_string(nl_json_batch)
 
